@@ -37,6 +37,8 @@ class TestDataAPI(unittest.TestCase):
                 num_float float,
                 num_integer integer,
                 ts TIMESTAMP WITH TIME ZONE,
+                field_null TEXT NULL,
+                field_boolean BOOLEAN NULL,
                 tz_notimezone TIMESTAMP
             );
             INSERT INTO aurora_data_api_test (a_name, doc, num_numeric, num_float, num_integer, ts, tz_notimezone)
@@ -61,6 +63,20 @@ class TestDataAPI(unittest.TestCase):
         self.assertEqual(1.11, row['num_float'])
         self.assertEqual(1, row['num_integer'])
 
+    def test_data_api_types(self):
+        sql = "INSERT INTO aurora_data_api_test (a_name, doc, num_numeric, num_float, num_integer, ts, tz_notimezone, field_null, field_boolean) values (:name, :doc, 1.12345, 1.11,:num_integer, '1976-11-02 08:45:00 UTC', '2021-03-03 15:51:48.082288', :field_null, :field_boolean) RETURNING id"
+        parameters = ParameterBuilder().add_string("name", 'prueba').add_null('field_null').add_json('doc', {'key':'as'}).add_long('num_integer',1).add_boolean('field_boolean', True).build()
+        result = self.data_client.execute(sql, parameters)
+        result_map = GraphQLMapper(result.metadata).map(result.records)
+        parameters = ParameterBuilder().add_long("id", result_map[0]['id']).build()
+        result = self.data_client.execute("select * from aurora_data_api_test where id =:id", parameters)
+        row = GraphQLMapper(result.metadata).map(result.records)[0]
+        self.assertEqual('prueba', row['a_name'])
+        self.assertEqual({'key':'as'}, row['doc'])
+        self.assertEqual(1, row['num_integer'])
+        self.assertEqual(True, row['field_boolean'])
+        self.assertEqual(None, row['field_null'])
+
     def test_transaction(self):
         transaction = self.data_client.begin_transaction()
         transaction.execute('''
